---
# This file is included in the footer of all pages
---

---

## 🔗 Quick Links

**📚 Documentation:** [Main Site](https://pcileechfwgenerator.ramseymcgrath.com) | [Search](/search) | [Site Map](/sitemap)

**🔧 Development:** [GitHub Repository](https://github.com/ramseymcgrath/PCILeechFWGenerator) | [Issues](https://github.com/ramseymcgrath/PCILeechFWGenerator/issues) | [Discussions](https://github.com/ramseymcgrath/PCILeechFWGenerator/discussions)

**📦 Installation:** [PyPI Package](https://pypi.org/project/pcileechfwgenerator/) | [Development Guide](/development)

**🌐 Related Projects:** [PCILeech](https://github.com/ufrisk/pcileech) | [PCILeech-FPGA](https://github.com/ufrisk/pcileech-fpga)

---

<small>**PCILeech Firmware Generator** - Generate authentic PCIe DMA firmware from real donor hardware.  
📖 [Documentation](https://pcileechfwgenerator.ramseymcgrath.com) • 💾 [Source Code](https://github.com/ramseymcgrath/PCILeechFWGenerator) • 📦 [PyPI](https://pypi.org/project/pcileechfwgenerator/)  
Made with ❤️ by [Ramsey McGrath](https://github.com/ramseymcgrath)</small>
